/* This file is part of Spectacle, the KDE screenshot utility
 * SPDX-FileCopyrightText: 2019 Boudhayan Gupta <bgupta@kde.org>
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

#include "Platform.h"

Platform::Platform(QObject *parent)
    : QObject(parent)
{
}

#include "moc_Platform.cpp"
